@@ -1,31 +1,8 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014  Aurélien Gâteau <agateau@kde.org>
+# SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
 #
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-#
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-# Python 2/3 compatibility (NB: we require at least 2.7)
-from __future__ import division, absolute_import, print_function, unicode_literals
-
+# SPDX-License-Identifier: BSD-2-Clause
 
 from fnmatch import fnmatch
 import logging
@@ -35,6 +12,7 @@ import subprocess
 import shutil
 import sys
 import tempfile
+import requests
 
 ## @package kapidox.utils
 #
@@ -68,6 +46,28 @@ def serialize_name(name):
     else:
         return None
 
+def set_repopath(id):
+    """ Return the repopath for the repo id, queried from projects.kde.org
+
+    Args:
+        id: unique KDE repo identifier
+    """
+    if id is None:
+        return None
+
+    try:
+        r = requests.get('https://projects.kde.org/api/v1/identifier/' + id)
+        return r.json()['repo']
+    except Exception as exc:
+        # Catch all exceptions here: whatever fails in this function should not
+        # cause the code to fail
+        logging.warning("Failed to get repository url for '{}' from projects.kde.org: {}".format(id, exc))
+        # This means there is no canonical repo identifier for this repo:
+        # generally that means that the repo was checked out into a non-
+        # canonical pathname (e.g. kitemviews checkout out into a directory
+        # called KItemViews, or kitemviews.git .. anything other than
+        # kitemviews is not recognized).
+        return None
 
 def set_maintainers(maintainer_keys, all_maintainers):
     """ Expend the name of the maintainers.
@@ -109,14 +109,18 @@ def parse_fancyname(fw_dir):
     """
     cmakelists_path = os.path.join(fw_dir, "CMakeLists.txt")
     if not os.path.exists(cmakelists_path):
+        for f in os.listdir(fw_dir):
+            if ".qbs" in f and not "Test" in f:
+                return f[:-4]
         logging.error("No CMakeLists.txt in {}".format(fw_dir))
         return None
-    project_re = re.compile(r"project\s*\(\s*([\w\-\_]+)", re.I)
+    project_re = re.compile(r"^\s*project\s*\(\s*([\w\-\_]+)", re.I | re.M)
     with open(cmakelists_path) as f:
-        for line in f.readlines():
-            match = project_re.search(line)
-            if match:
-                return match.group(1)
+        cmakelists_content = f.read()
+        match = project_re.search(cmakelists_content)
+        if match:
+            return match.group(1)
+
     logging.error("Failed to find framework name: Could not find a "
                   "'project()' command in {}.".format(cmakelists_path))
     return None
@@ -159,7 +163,7 @@ def svn_export(remote, local, overwrite=False):
 
     Args:
         remote:     (string) the remote url.
-        local:      (string) the local path where to dowload.
+        local:      (string) the local path where to download.
         overwrite:  (bool) whether to overwrite `local` or not. (optional,
     default = False)
 
